# OpenAuth

OpenAuth is a Library that provides a variety of authentication methods using Deta as the database.

## Authentication

- [x] Username & Password OAuth
- [x] Magic Links
- ### Social Auth
    - [x] GitHub
    - [ ] Google
    - [ ] Apple
    - [ ] Twitter
    - [x] Spotify
    - [x] Discord
    - [ ] Microsoft
    - [ ] Facebook